@@ -76,7 +76,7 @@ public:
                                     got_overloads_choice_signal () const;
 
     sigc::signal<void, const IDebugger::BreakPoint&, int, const UString&>&
-                                            breakpoint_deleted_signal () const ;
+                                        breakpoint_deleted_signal () const ;
 
     sigc::signal<void, const IDebugger::BreakPoint&, int>&
                                         breakpoint_disabled_signal () const ;
@@ -102,7 +102,7 @@ public:
 
     sigc::signal<void,
                  int,
-                 const Frame&,
+                 const Frame* const,
                  const UString&>& thread_selected_signal () const  ;
 
     sigc::signal<void,
@@ -238,10 +238,13 @@ public:
     void set_debugger_parameter (const UString &a_name,
                                  const UString &a_value) ;
     void set_solib_prefix_path (const UString &a_name) ;
-    void load_program (const UString &a_prog_with_args,
+
+    void load_program (const UString &a_prog,
+                       const vector<UString> &a_args,
                        const UString &a_working_dir) ;
 
-    void load_program (const vector<UString> &a_argv,
+    void load_program (const UString &a_prog,
+                       const vector<UString> &a_argv,
                        const UString &working_dir,
                        const vector<UString> &a_source_search_dirs,
                        const UString &a_tty_path) ;
@@ -290,6 +293,14 @@ public:
 
     void set_current_frame_level (int);
 
+    const UString& get_current_frame_address () const;
+
+    void set_current_frame_address (const UString &a_address);
+
+    void get_mi_thread_location (UString &a_str) const;
+
+    void get_mi_thread_and_frame_location (UString &a_str) const;
+
     void step_in (const UString &a_cookie) ;
 
     void step_out (const UString &a_cookie) ;
@@ -311,6 +322,20 @@ public:
                          const UString &a_condition,
                          const UString &a_cookie)  ;
 
+    void enable_breakpoint (gint a_break_num,
+                            const UString &a_cookie="");
+
+    void disable_breakpoint (gint a_break_num,
+                             const UString &a_cookie="");
+
+    void set_breakpoint_ignore_count (gint a_break_num,
+                                      gint a_ignore_count,
+                                      const UString &a_cookie = "");
+
+    void delete_breakpoint (const UString &a_path,
+                            gint a_line_num,
+                            const UString &a_cookie) ;
+
     void set_watchpoint (const UString &a_expression,
                          bool a_write, bool a_read,
                          const UString &a_cookie);
@@ -322,15 +347,6 @@ public:
     void set_catch (const UString &a_event,
                     const UString &a_cookie)  ;
 
-    void enable_breakpoint (gint a_break_num,
-                            const UString &a_cookie="");
-
-    void disable_breakpoint (gint a_break_num,
-                             const UString &a_cookie="");
-
-    void delete_breakpoint (const UString &a_path,
-                            gint a_line_num,
-                            const UString &a_cookie) ;
 
     void choose_function_overload (int a_overload_number,
                                    const UString &a_cookie) ;
@@ -343,6 +359,8 @@ public:
     void select_thread (unsigned int a_thread_id,
                         const UString &a_cookie) ;
 
+    unsigned int get_current_thread () const;
+
     void delete_breakpoint (gint a_break_num,
                             const UString &a_cookie) ;
 
